==> cetus-5.3.5.tgz: package/index.js <==
"use strict";

let config                  =   null,
    logger                  =   require('./logger'),
    env                     =   process.env.NODE_ENV || 'development',
    returnExports           =   {
                                    AWS:            require('aws-sdk'),
                                    auth:           require('./auth'),
                                    config:         {},
                                    crypto:         require('./crypto'),
                                    database:       require('./database'),
                                    dbLock:         {lock: () => {}},
                                    env:            env,
                                    error:          require('./error'),
                                    events:         require('./events'),
                                    initialized:    false,
                                    interfaces:     require('./interfaces'),
                                    logger:         logger,
                                    mailer:         require('./mailer'),
                                    mongoose:       require('mongoose'),
                                    notify:         require('./notify'),
                                    parser:         require('./parser'),
                                    payments:       require('./payments'),
                                    passport:       require('passport'),
                                    redis:          {client: () => {}, lock: require('redislock')},
                                    search:         require('./search'),
                                    sessions:       require('./sessions'),
                                    storage:        require('./storage'),
                                    utilities:      require('./utilities'),
                                    validator:      require('./validator'),
                                };

returnExports.init = function (options) {
    config = options,
    logger.init(options.logger);

    let cluster                 =   require('cluster'),
        numCPUs                 =   require('os').cpus().length,
        worker                  =   require('./worker'),
        timeouts                =   [];

    returnExports.config = config;
    returnExports.AWS.config.setPromisesDependency(require('bluebird'));
    // returnExports.mongoose.Promise = require('bluebird');

    if (cluster.isMaster) {

        // Fork workers.
        for (let i = 0; i < numCPUs; i++) {
            logger.info  ("utlWebServer init - Forking a Worker");
            if (process.env.AWS_ACCESS_KEY_ID) logger.info  ("utlWebServer init - Using AWS Access Key Id: " + process.env.AWS_ACCESS_KEY_ID);
            cluster.fork();
        }

        cluster.on('fork', worker => timeouts[worker.id] = setTimeout ( () => logger.warn('utlWebServer init Worker #' + worker.id +' is not listening yet. Something must be wrong.'), 5000) );

        cluster.on('listening', function (worker, address) {
            clearTimeout(timeouts[worker.id]);
            logger.info('utlWebServer init Worker #' + worker.id + ' now listening on port ' + address.port);
        });

        cluster.on('exit', function(worker, code, signal) {
            logger.error('utlWebServer init Worker #' + worker.id + ' ( ' + worker.process.pid + ') died ('+code+')');
            if (timeouts[worker.id]) clearTimeout(timeouts[worker.id]);
            // if (cluster.workers.length < numCPUs) cluster.fork();
            logger.error(cluster.workers);
            cluster.fork();
        });

        cluster.on('disconnect', function(worker) {
            logger.error('Worker #' + worker.id + ' ( ' + worker.process.pid + ') has disconnected');
            if (timeouts[worker.id]) clearTimeout(timeouts[worker.id]);
            cluster.fork();
        });

    } else {
        worker.init(config);
    }

    returnExports.dbLock.lock = worker.dbLock;
    returnExports.initialized = true;
    returnExports.redis.client = worker.redisClient;
    returnExports.redis.lock.setDefaults(config.server.dbLock.redisLockDefaults)

};

module.exports = returnExports;

==> cetus-8.0.30.tgz: package/index.js <==
"use strict";

let config                  =   null,
    logger                  =   require('./logger'),
    env                     =   process.env.NODE_ENV || 'development',
    returnExports           =   {
                                    AWS:            require('aws-sdk'),
                                    auth:           require('./auth'),
                                    config:         {},
                                    crypto:         require('./crypto'),
                                    database:       require('./database'),
                                    dbLock:         {lock: () => {}},
                                    env:            env,
                                    error:          require('./error'),
                                    events:         require('./events'),
                                    initialized:    false,
                                    interfaces:     require('./interfaces'),
                                    logger:         logger,
                                    mailer:         require('./mailer'),
                                    mongoose:       require('mongoose'),
                                    notify:         require('./notify'),
                                    parser:         require('./parser'),
                                    payments:       require('./payments'),
                                    passport:       require('passport'),
                                    redis:          {client: () => {}, lock: require('redislock')},
                                    search:         require('./search'),
                                    sessions:       require('./sessions'),
                                    storage:        require('./storage'),
                                    utilities:      require('./utilities'),
                                    validator:      require('./validator'),
                                };

returnExports.init = function (options) {
    config = options,
    logger.init(options.logger);

    let cluster                 =   require('cluster'),
        numCPUs                 =   require('os').cpus().length,
        worker                  =   require('./worker'),
        timeouts                =   [];

    returnExports.config = config;
    returnExports.AWS.config.setPromisesDependency(require('bluebird'));

    if (cluster.isMaster) {

        // Fork workers.
        const numWorkers = (process.env.NUM_WORKERS) || numCPUs;
        for (let i = 0; i < numWorkers; i++) {
            logger.info  ("utlWebServer init - Forking a Worker");
            if (process.env.AWS_ACCESS_KEY_ID) logger.info  ("utlWebServer init - Using AWS Access Key Id: " + process.env.AWS_ACCESS_KEY_ID);
            cluster.fork();
        }

        cluster.on('fork', worker => timeouts[worker.id] = setTimeout ( () => logger.warn('utlWebServer init Worker #' + worker.id +' is not listening yet. Something must be wrong.'), 5000) );

        cluster.on('listening', function (worker, address) {
            clearTimeout(timeouts[worker.id]);
            logger.info('utlWebServer init Worker #' + worker.id + ' now listening on port ' + address.port);
        });

        cluster.on('exit', function(worker, code, signal) {
            logger.error('utlWebServer init Worker #' + worker.id + ' ( ' + worker.process.pid + ') died ('+code+')');
            if (timeouts[worker.id]) clearTimeout(timeouts[worker.id]);
            // if (cluster.workers.length < numCPUs) cluster.fork();
            logger.error(cluster.workers);
            cluster.fork();
        });

        cluster.on('disconnect', function(worker) {
            logger.error('Worker #' + worker.id + ' ( ' + worker.process.pid + ') has disconnected');
            if (timeouts[worker.id]) clearTimeout(timeouts[worker.id]);
            cluster.fork();
        });

    } else {
        worker.init(config);
    }

    returnExports.dbLock.lock = worker.dbLock;
    returnExports.initialized = true;
    returnExports.redis.client = worker.redisClient;
    returnExports.redis.lock.setDefaults(config.server.dbLock.redisLockDefaults)

};

module.exports = returnExports;
